@@ -61,8 +61,13 @@ returned as sentences.
 
 =item add_acronyms( @acronyms )
 
-This function is used for adding acronyms not supported by this code.Note that
-acronyms are seaerched for on a case insensive basis.
+This function is used for adding acronyms not supported by this code.
+The input should be regular expressions for matching the desired acronyms,
+but should not include the final period (C<.>). So, for example, C<blv?d>
+matches C<blvd.> and C<bld.>. C<a\.mlf> will match C<a.mlf.>. You do not
+need to bother with acronyms consisting of single letters and dots
+(e.g. "U.S.A."), as these are found automatically. Note also that acronyms
+are searched for on a case insensitive basis.
 
 Please see`Acronym/Abbreviations list' section for the abbreviations already
 supported by this module.
@@ -73,7 +78,9 @@ This function will return the defined list of acronyms.
 
 =item set_acronyms( @my_acronyms )
 
-This function replaces the predefined acroym list with the given list.
+This function replaces the predefined acronym list with the given list. See
+L</add_acronyms> for details on the input specifications.
+
 
 =item get_EOS( )
 
@@ -174,7 +181,7 @@ use vars qw/$VERSION @ISA @EXPORT_OK $EOS $LOC $AP $P $PAP @ABBREVIATIONS/;
 use Carp qw/cluck/;
 use English;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 # LC_CTYPE now in locale "French, Canada, codeset ISO 8859-1"
 our $LOC;
@@ -354,7 +361,7 @@ sub remove_false_end_of_sentence {
 	$marked_segment=~s/([^-\w]\w$PAP\s)$EOS/$1/sg;
 	$marked_segment=~s/([^-\w]\w$P)$EOS/$1/sg;         
 
-	# don't plit after a white-space followed by a single letter followed
+	# don't split after a white-space followed by a single letter followed
 	# by a dot followed by another whitespace.
 	$marked_segment=~s/(\s\w\.\s+)$EOS/$1/sg; 
 
@@ -363,7 +370,6 @@ sub remove_false_end_of_sentence {
 	# fix "." "?" "!"
 	$marked_segment=~s/(['"]$P['"]\s+)$EOS/$1/sg;
 	## fix where abbreviations exist
-	foreach (@ABBREVIATIONS) { $marked_segment=~s/(\b$_$PAP\s)$EOS/$1/isg; }
 	$marked_segment=~s/$abbreviation_regex/$1/g;
 	
 	# don't break after quote unless its a capital letter.
